@@ -66,7 +66,7 @@ About::About( QWidget* parent )
 	tabLayout1->addWidget( PixmapLabel1 );
 	BuildID = new QLabel( tab, "BB" );
 	BuildID->setAlignment(Qt::AlignCenter);
-	QString bu = tr("%1 %2 %3 ").arg("05").arg("July").arg("2005");
+	QString bu = tr("%1 %2 %3 ").arg("5").arg("January").arg("2006");
 #ifdef HAVE_CMS
 	bu += "C";
 #else
@@ -101,6 +101,7 @@ About::About( QWidget* parent )
 										"<tr><td>Petr Vaněk</td><td>petr@yarpen.cz</td></tr>" +
 										"<tr><td>Riku Leino</td><td>riku.leino@gmail.com</td></tr>"+
 										"<tr><td>Craig  Ringer</td><td>craig@postnewspapers.com.au</td></tr>" +
+										"<tr><td>Andreas Vox</td><td>avox@arcor.de</td></tr>" +
 										"<tr><td> </td><td> </td></tr>" +
 										"<tr><td><b>" + tr("Contributions from:").utf8()  + "</b></td><td></td></tr>" +
 										"<tr><td>Niyam Bhushan</td><td></td></tr>" +
@@ -111,7 +112,7 @@ About::About( QWidget* parent )
 										"<tr><td>Maciej Hański</td><td>m.hanski@gmx.at</td></tr>" +
 										"<tr><td>Oleksandr Moskalenko</td><td>malex@tagancha.org</td></tr>" +
 										"<tr><td>Marti Maria</td><td></td></tr>" +
-										"<tr><td>Alexandre Prokoudine</td><td>techwriter@land.ru</td></tr>"
+										"<tr><td>Alexandre Prokoudine</td><td>alexandre.prokoudine@gmail.com</td></tr>"
 										"<tr><td>Alessandro Rimoldi</td><td>http://ideale.ch/contact</td></tr>" +
 										"<tr><td>Alastair Robinson</td><td>blackfive@fakenhamweb.co.uk</td></tr>" +
 										"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" +
@@ -130,6 +131,7 @@ About::About( QWidget* parent )
 										"<tr><td>Craig Bradney</td><td>cbradney@zip.com.au</td></tr>" +
 										"<tr><td>Frédéric Dubuy</td><td>effediwhy@gmail.com</td></tr>" +
 										"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" + 
+										"<tr><td>Volker Ribbert</td><td>volkerius@h3c.de</td></tr>" + 
 										"<tr><td>Louis Desjardins</td><td>louisdesjardins@videotron.ca</td></tr>" + 
 										"<tr><td> </td><td> </td></tr>" +
 
@@ -175,8 +177,11 @@ About::About( QWidget* parent )
 	                                      "<tr><td>Louis Desjardins</td><td>louis_desjardins@mardigrafe.com</td></tr>" +
 	                                      "<tr><td>Frédéric Dubuy</td><td>effediwhy@gmail.com</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +
+					      "<tr><td><b>" + tr("Galician:").utf8()  + "</b></td><td> </td></tr>" +
+	                                      "<tr><td>Xose Calvo</td><td>scribus@galizaweb.net</td></tr>" +
 	                                      "<tr><td><b>" + tr("German:").utf8()  + "</b></td><td> </td></tr>" +
 	                                      "<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" +
+					      "<tr><td>Christoph Schäfer</td><td>christoph-schaefer@gmx.de</td></tr>" +
 	                                      "<tr><td>Franz Schmid</td><td>Franz.Schmid@altmuehlnet.de</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +
 	                                      "<tr><td><b>" + tr("Italian:").utf8()  + "</b></td><td> </td></tr>" +
@@ -196,7 +201,7 @@ About::About( QWidget* parent )
                                           "<tr><td>Frederico Gon&#231;alves</td><td></td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +	
 	                                      "<tr><td><b>" + tr("Russian:").utf8()  + "</b></td><td></td></tr>" +
-	                                      "<tr><td>Alexandre Prokoudine</td><td>techwriter@land.ru</td></tr>" +
+	                                      "<tr><td>Alexandre Prokoudine</td><td>alexandre.prokoudine@gmail.com</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +
 	                                      "<tr><td><b>" + tr("Serbian:").utf8()  + "</b></td><td></td></tr>" +
 	                                      "<tr><td>Bojan Božovi&#263;</td><td>bole89@infosky.net</td></tr>" +
@@ -240,7 +245,6 @@ About::About( QWidget* parent )
 	                                      "<tr><td>Yves Ceccone</td><td>yves@yeccoe.org</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +
 	                                      "<tr><td><b>" + tr("Galician:").utf8()  + "</b></td><td> </td></tr>" +
-	                                      "<tr><td>Xose Calvo</td><td>xosecalvo@galizaweb.net</td></tr>" +
 	                                      "<tr><td>Manuel Anxo Rei</td><td>manxopar@avogaciagalega.org</td></tr>" +
 	                                      "<tr><td> </td><td> </td></tr>" +                                      
 	                                      "<tr><td><b>" + tr("Hungarian:").utf8()  + "</b></td><td> </td></tr>" +
