@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "pdfopts.h"
 #include "pdfopts.moc"
 #include "customfdialog.h"
@@ -24,7 +32,7 @@ extern PrefsFile* prefsFile;
 PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFonts, ScribusView *vie, PDFOpt *Optionen, QValueList<PreSet> Eff, ProfilesL *PDFXProfiles, SCFonts &AllFonts)
 		: QDialog( parent, "pdf", true, 0 )
 {
-	setCaption( tr( "Create PDF File" ) );
+	setCaption( tr( "Save as PDF" ) );
 	setIcon(loadIcon("AppIcon.png"));
 	FontsToEmbed.clear();
 	view = vie;
@@ -756,6 +764,7 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
 	BleedLeft->setMinValue(0);
 	BleedLeft->setMaxValue(view->Doc->PageB*UmReFaktor);
 	BleedLeft->setValue(Optionen->BleedLeft*UmReFaktor);
+/*
 #ifdef HAVE_CMS
 	if ((!CMSuse) || (!CMSavail))
 		Options->setTabEnabled(tabPDFX, false);
@@ -765,6 +774,38 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
 		Options->setTabEnabled(tabPDFX, false);
 #else
 	Options->setTabEnabled(tabPDFX, false);
+#endif
+*/
+#ifdef HAVE_CMS
+	if ((!CMSavail) || (!CMSuse) || (PDFXProfiles->isEmpty()))
+	{
+		Options->setTabToolTip(tabPDFX,
+			tr("<qt>Color management must be enabled to use PDF/X-3. "
+			   "You can enable color management from the Settings menu.</qt>"));
+		Options->setTabEnabled(tabPDFX, false);
+	}
+	else if (Optionen->Version == 12)
+	{
+		// PDF/X only possible with PDF 1.2, which has been selected so we enable
+		// access to the PDF/X UI.
+		// enablePDFX is usually triggered by a change in the PDF version combo box.
+		// 2 is the index of PDF/X-3 in the combo box.
+		EnablePDFX(2);
+	}
+	else
+	{
+		// PDF/X-3 is off since we're using another PDF version, so disable access
+		// to the PDF/X UI.
+		Options->setTabEnabled(tabPDFX, false);
+		Options->setTabToolTip(tabPDFX,
+			tr("<qt>PDF/X-3 is supported and enabled, but can not be used for "
+				"the selected PDF version. If you want to use PDF/X-3, you need "
+				"to set PDF/X-3 as your PDF version (compatibility level).</qt>"));
+	}
+#else
+	Options->setTabEnabled(tabPDFX, false);
+	Options->setTabToolTip(tabPDFX,
+		tr("<qt>PDF/X-3 is not supported by this Scribus build (CMS support not present).</qt>"));
 #endif
 	BleedChanged();
 	PgSel = 0;
@@ -827,16 +868,16 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
 			              "a token can be * for all the pages, 1-5 for\n"
 			              "a range of pages or a single page number.") );
 
-	QToolTip::add( ComboBox1, tr( "Determines the PDF compatibility. The default is Acrobat 4.0 which gives the widest compatibility.\nChoose Acrobat 5.0 if your file has PDF 1.4 features such as transparency or you require 128 bit encryption.\nPDF/X-3 is for exporting the PDF for commercial printing and is selectable when you have activated color management." ) );
+	QToolTip::add( ComboBox1, "<qt>" + tr( "Determines the PDF compatibility. The default is Acrobat 4.0 which gives the widest compatibility. Choose Acrobat 5.0 if your file has PDF 1.4 features such as transparency or you require 128 bit encryption. PDF/X-3 is for exporting the PDF when you want color managed RGB for " "commercial printing and is selectable when you have activated color management. Note: PDF/X-3 will convert all CMYK images to ICC based RGB colors. Use only when advised by your printer or in some cases printing to a 4 color digital color laser printer.") + "</qt>" );
 	QToolTip::add( ComboBind, tr( "Determines the binding of pages in the PDF. Unless you know\nyou need to change it leave the default choice - Left." ) );
 	QToolTip::add( CheckBox1, tr( "Generates thumbnails of each page in the PDF.\nSome viewers can use the thumbnails for navigation." ) );
 	QToolTip::add( Article, tr( "Generate PDF Articles, which is useful for navigating linked articles in a PDF." ) );
 	QToolTip::add( CheckBM, tr( "Embed the bookmarks you created in your document.\nThese are useful for navigating long PDF documents." ) );
 	QToolTip::add( Resolution, tr( "Export resolution of text and vector graphics.\nThis does not affect the resolution of bitmap images like photos." ) );
-	QToolTip::add( Compression, tr( "Compression of text and graphics.\nUnless you have a reason, leave this checked. This reduces PDF size." ) );
-	QToolTip::add( CMethod, tr( "Version of compression for images.\nAutomatic allows Scribus to choose the best method.\nZIP is good for images with solid colors.\nJPEG is better at creating smaller PDF files which have many photos (with slight image loss possible).\nLeave it set to automatic, unless you have a need for special compression options." ) );
+	QToolTip::add( Compression, tr( " Lossless compression of text and graphics.\nUnless you have a reason, leave this checked. This reduces PDF size." ) );
+	QToolTip::add( CMethod, "<qt>" + tr( "Method of compression to use for images. Automatic allows Scribus to choose the best method. ZIP is lossless and good for images with solid colors. JPEG is better at creating smaller PDF files which have many photos (with slight image quality loss possible). Leave it set to Automatic, unless you have a need for special compression options." ) + "</qt>");
 	QToolTip::add( CQuality, tr( "Compression levels: Minimum (25%), Low (50%), Medium (75%), High (85%), Maximum (95%)" ) );
-	QToolTip::add( DSColor, tr( "Downsample your bitmap images to the selected DPI.\nLeaving this unchecked will render them at their native resolution." ) );
+	QToolTip::add( DSColor, tr( "Re-sample your bitmap images to the selected DPI.\nLeaving this unchecked will render them at their native resolution.\nThis can increase memory usage and slow down export." ) );
 	QToolTip::add( ValC, tr( "DPI (Dots Per Inch) for image export.") );
 	QToolTip::add( EmbedFonts, tr( "Embed fonts into the PDF. Embedding the fonts\nwill preserve the layout and appearance of your document." ) );
 	QToolTip::add( CheckBox10, tr( "Enables presentation effects when using Acrobat Reader in full screen mode." ) );
@@ -854,7 +895,7 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
 	QToolTip::add( PrintSec, tr( "Allow printing of the PDF. If un-checked, printing is prevented. " ) );
 	QToolTip::add( ModifySec, tr( "Allow modifying of the PDF. If un-checked, modifying the PDF is prevented." ) );
 	QToolTip::add( CopySec, tr( "Allow copying of text or graphics from the PDF. \nIf un-checked, text and graphics cannot be copied." ) );
-	QToolTip::add( AddSec, tr( "Allow adding annotations and fields to the PDF. \nIf un-checked, editing annotations and fileds is prevented." ) );
+	QToolTip::add( AddSec, tr( "Allow adding annotations and fields to the PDF. \nIf un-checked, editing annotations and fields is prevented." ) );
 	QToolTip::add( OutCombo, tr( "Color model for the output of your PDF.\nChoose Screen/Web for PDFs which are used for screen display and for printing on typical inkjets.\nChoose Printer when printing to a true 4 color CMYK printer." ) );
 	QToolTip::add( UseLPI, tr( "This is an advanced setting which is not enabled by default. This should only be enabled\nwhen specifically requested by your printer and they have given you the exact details needed.\nOtherwise, your exported PDF may not print properly and is truly not portable across systems." ) );
 	QToolTip::add( EmbedProfs, tr( "Embed a color profile for solid colors" ) );
@@ -877,6 +918,8 @@ PDF_Opts::PDF_Opts( QWidget* parent,  QString Fname, QMap<QString,QFont> DocFont
 	connect( FileC, SIGNAL( clicked() ), this, SLOT( ChangeFile() ) );
 	connect( OK, SIGNAL( clicked() ), this, SLOT( DoExport() ) );
 	connect( Cancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
+	connect( Datei, SIGNAL( lostFocus() ), this, SLOT( filenameChanged() ) );
+	connect( Datei, SIGNAL( returnPressed() ), this, SLOT( filenameChanged() ) );
 	connect(EmbedFonts, SIGNAL(clicked()), this, SLOT(EmbedAll()));
 	connect(AvailFlist, SIGNAL(clicked(QListBoxItem*)), this, SLOT(SelAFont(QListBoxItem*)));
 	connect(EmbedList, SIGNAL(clicked(QListBoxItem*)), this, SLOT(SelEFont(QListBoxItem*)));
@@ -973,18 +1016,34 @@ void PDF_Opts::BleedChanged()
 	p.end();
 }
 
-void PDF_Opts::EnablePDFX(int a)
+void PDF_Opts::EnablePDFX(int comboIndex)
 {
-	if (a != 2)
+	if (comboIndex != 2)
 	{
+		// Disable access to PDF/X settings and re-enable security settings
 		Options->setTabEnabled(tabPDFX, false);
+		Options->setTabToolTip(tabPDFX,
+			tr("<qt>PDF/X-3 is supported and enabled, but can not be used for "
+				"the selected PDF version. If you want to use PDF/X-3, you need "
+				"to set PDF/X-3 as your PDF version (compatibility level).</qt>"));
 		Options->setTabEnabled(tabSecurity, true);
+		Options->setTabToolTip(tabSecurity, tr("PDF security settings"));
 		EmbedProfs2->setEnabled(true);
 		CheckBox10->setEnabled(true);
 		EmbedFonts->setEnabled(true);
 		OutCombo->setEnabled(true);
+		OK->setEnabled(true);
 		return;
 	}
+	// PDF/X-3 selected
+	// Let user tweak PDF/X settings and disable access to security settings
+	Options->setTabEnabled(tabPDFX, true);
+	Options->setTabToolTip(tabPDFX, tr("PDF/X-3 settings"));
+	Options->setTabEnabled(tabSecurity, false);
+	Options->setTabToolTip(tabSecurity,
+		tr("<qt>PDF security can not be used with PDF/X-3. If you want to turn "
+			"on security, change your PDF version (compatibility level) to "
+			"something other than PDF/X-3.</qt>"));
 	EmbedFonts->setChecked(true);
 	EmbedAll();
 	CheckBox10->setChecked(false);
@@ -997,8 +1056,6 @@ void PDF_Opts::EnablePDFX(int a)
 	CheckBox10->setEnabled(false);
 	EmbedFonts->setEnabled(false);
 	EnablePGI();
-	Options->setTabEnabled(tabPDFX, true);
-	Options->setTabEnabled(tabSecurity, false);
 	if (InfoString->text() == "")
 		OK->setEnabled(false);
 	connect(OutCombo, SIGNAL(activated(int)), this, SLOT(EnablePr(int)));
@@ -1423,3 +1480,15 @@ void PDF_Opts::ChangeFile()
 		return;
 	Datei->setText(fn);
 }
+
+void PDF_Opts::filenameChanged()
+{
+	QString currentText=Datei->text();
+	if (currentText.right(1)==".")
+	{
+		Datei->setText(currentText+"pdf");
+		return;
+	}
+	if (currentText.right(4).lower()!=".pdf")
+		Datei->setText(currentText+".pdf");
+}
