@@ -31,7 +31,8 @@
  
  extern xmlSAXHandlerPtr sSAXHandler;
  
-StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool prefix)
+StyleReader::StyleReader(QString documentName, gtWriter *w,
+                         bool textOnly, bool prefix, bool combineStyles)
 {
  	sreader      = this;
  	docname      = documentName;
@@ -39,6 +40,7 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  	writer       = w;
  	importTextOnly = textOnly;
  	usePrefix    = prefix;
+ 	packStyles   = combineStyles;
  	currentStyle = NULL;
  	parentStyle  = NULL;
  	inList       = false;
@@ -199,7 +201,7 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  			size = getSize(attrs.value(i), psize);
  			int nsize = static_cast<int>(size * 10);
  			currentStyle->getFont()->setSize(nsize);
- 			if ((currentStyle->getName() == "default-style") && (pstyle != NULL))
+ 			if (pstyle)
  				pstyle->setLineSpacing(writer->getPreferredLineSpacing(nsize));
  		}
  		else if ((attrs.localName(i) == "fo:line-height") && (parentStyle != NULL))
@@ -453,7 +455,7 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  {
  	gtParagraphStyle *s;
  	QString tname = style->getName();
- 	if (style->target() == "paragraph")
+ 	if ((style->target() == "paragraph") && (packStyles))
  	{
  		s = dynamic_cast<gtParagraphStyle*>(style);
  		QString nameByAttrs = QString("%1-").arg(s->getSpaceAbove());
@@ -484,6 +486,12 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  			tname = style->getName();
  		}
  	}
+ 	else if (!packStyles)
+ 	{
+ 		attrsStyles[name] = style;
+ 		pstyleCounts[name] = 1;
+ 		tname = style->getName();
+ 	}
  	if (!styles.contains(name))
  	{
  		if ((tname.find(docname) == -1) && (usePrefix))
@@ -546,7 +554,7 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  		size = getSize(value, psize);
  		int nsize = static_cast<int>(size * 10);
  		style->getFont()->setSize(nsize);
- 		if ((style->getName() == "default-style") && (pstyle != NULL))
+ 		if (pstyle)
  			pstyle->setLineSpacing(writer->getPreferredLineSpacing(nsize));
  	}
  	else if ((key == "fo:line-height") && (parent2Style != NULL))
@@ -641,29 +649,29 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  	if (lowerValue.find("pt") != -1)
  	{
  		dbl = lowerValue.remove("pt");
- 		ret = gtMeasure::d2d(dbl.toDouble(), PT);
+ 		ret = gtMeasure::d2d(dbl.toDouble(), SC_PT);
  	}
  	else if (lowerValue.find("mm") != -1)
  	{
  		dbl = lowerValue.remove("mm");
- 		ret = gtMeasure::d2d(dbl.toDouble(), MM);
+ 		ret = gtMeasure::d2d(dbl.toDouble(), SC_MM);
  	}
  	else if (lowerValue.find("cm") != -1)
  	{
  		dbl = lowerValue.remove("cm");
- 		ret = gtMeasure::d2d(dbl.toDouble() * 10, MM);
+ 		ret = gtMeasure::d2d(dbl.toDouble() * 10, SC_MM);
  	}
  	else if (lowerValue.find("in") != -1)
  	{
  		dbl = lowerValue.remove("inch");
  		dbl = lowerValue.remove("in");
- 		ret = gtMeasure::d2d(dbl.toDouble(), IN);
+ 		ret = gtMeasure::d2d(dbl.toDouble(), SC_IN);
  	}
  	else if (lowerValue.find("pi") != -1)
  	{
  		dbl = lowerValue.remove("pica");
  		dbl = lowerValue.remove("pi");
- 		ret = gtMeasure::d2d(dbl.toDouble(), P);
+ 		ret = gtMeasure::d2d(dbl.toDouble(), SC_P);
  	}
  	else if (lowerValue.find("%") != -1)
  	{
@@ -734,7 +742,7 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  
  xmlSAXHandlerPtr sSAXHandler = &sSAXHandlerStruct;
  
- void StyleReader::startElement(void *user_data, const xmlChar * fullname, const xmlChar ** atts)
+ void StyleReader::startElement(void*, const xmlChar * fullname, const xmlChar ** atts)
  {
  	QString* name = new QString((const char*) fullname);
  	name = new QString(name->lower());
@@ -747,7 +755,7 @@ StyleReader::StyleReader(QString documentName, gtWriter *w, bool textOnly, bool
  	sreader->startElement(NULL, NULL, *name, *attrs);
  }
  
- void StyleReader::endElement(void *user_data, const xmlChar * name)
+ void StyleReader::endElement(void*, const xmlChar * name)
  {
  	QString *nname = new QString((const char*) name);
  	nname = new QString(nname->lower());
