@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "objpdffile.h"
 #include "cmdutil.h"
 
@@ -1139,7 +1147,7 @@ static PyObject *PDFfile_save(PDFfile *self)
         }
         ReOrderText(Carrier->doc, Carrier->view);
         if (!Carrier->getPDFDriver(fn, nam, Components, pageNs, thumbs)) {
-                fn = "Can't write the File: " + fn;
+                fn = "Cannot write the File: " + fn;
                 PyErr_SetString(PyExc_SystemError, fn.ascii());
                 return NULL;
         }
