@@ -26,6 +26,8 @@
  #include "config.h"
 #endif
 
+#include <assert.h>
+
 #include "pageback.h"
 #include <qcolor.h>
 #include <qfont.h>
@@ -1424,7 +1426,10 @@ void ScribusView::CreatePS(PSLib *p, std::vector<int> &pageNs, bool sep, QString
 								{
 									SetClipPath(p, &ite->PoLine);
 									p->PS_closepath();
-									p->PS_fill();
+									if (ite->GrType != 0)
+										HandleGradient(p, ite, ite->Width, ite->Height, gcr);
+									else
+										p->PS_fill();
 								}
 								if ((ite->flippedH % 2) != 0)
 								{
@@ -2612,7 +2617,7 @@ void ScribusView::SetClipPath(PSLib *p, FPointArray *c, bool poly)
 
 void ScribusView::contentsWheelEvent(QWheelEvent *w)
 {
-	if ((Doc->ActPage->Mpressed) && (Doc->ActPage->MidButt))
+	if ((Doc->ActPage->Mpressed) && (Doc->ActPage->MidButt) || ( w->state() & ControlButton ))
 	{
 		w->delta() > 0 ? slotZoomIn2() : slotZoomOut2();
 	}
